# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKClassifiersPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkScalarImageKmeansImageFilterPython
else:
    import _itkScalarImageKmeansImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.pyBasePython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkArrayPython

def itkScalarImageKmeansImageFilterIF2ISS2_New():
    return itkScalarImageKmeansImageFilterIF2ISS2.New()

class itkScalarImageKmeansImageFilterIF2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2ISS2):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIF2ISS2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIF2ISS2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion2"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIF2ISS2

        Create a new object of the class itkScalarImageKmeansImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIF2ISS2 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2ISS2_swigregister(itkScalarImageKmeansImageFilterIF2ISS2)

def itkScalarImageKmeansImageFilterIF2IUC2_New():
    return itkScalarImageKmeansImageFilterIF2IUC2.New()

class itkScalarImageKmeansImageFilterIF2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IUC2):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIF2IUC2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIF2IUC2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion2"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIF2IUC2

        Create a new object of the class itkScalarImageKmeansImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIF2IUC2 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF2IUC2_swigregister(itkScalarImageKmeansImageFilterIF2IUC2)

def itkScalarImageKmeansImageFilterIF3ISS3_New():
    return itkScalarImageKmeansImageFilterIF3ISS3.New()

class itkScalarImageKmeansImageFilterIF3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3ISS3):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIF3ISS3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIF3ISS3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion3"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIF3ISS3

        Create a new object of the class itkScalarImageKmeansImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIF3ISS3 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3ISS3_swigregister(itkScalarImageKmeansImageFilterIF3ISS3)

def itkScalarImageKmeansImageFilterIF3IUC3_New():
    return itkScalarImageKmeansImageFilterIF3IUC3.New()

class itkScalarImageKmeansImageFilterIF3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IUC3):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIF3IUC3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIF3IUC3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion3"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIF3IUC3

        Create a new object of the class itkScalarImageKmeansImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIF3IUC3 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIF3IUC3_swigregister(itkScalarImageKmeansImageFilterIF3IUC3)

def itkScalarImageKmeansImageFilterISS2ISS2_New():
    return itkScalarImageKmeansImageFilterISS2ISS2.New()

class itkScalarImageKmeansImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterISS2ISS2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterISS2ISS2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion2"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterISS2ISS2

        Create a new object of the class itkScalarImageKmeansImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterISS2ISS2 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2ISS2_swigregister(itkScalarImageKmeansImageFilterISS2ISS2)

def itkScalarImageKmeansImageFilterISS2IUC2_New():
    return itkScalarImageKmeansImageFilterISS2IUC2.New()

class itkScalarImageKmeansImageFilterISS2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2IUC2):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterISS2IUC2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterISS2IUC2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion2"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterISS2IUC2

        Create a new object of the class itkScalarImageKmeansImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterISS2IUC2 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS2IUC2_swigregister(itkScalarImageKmeansImageFilterISS2IUC2)

def itkScalarImageKmeansImageFilterISS3ISS3_New():
    return itkScalarImageKmeansImageFilterISS3ISS3.New()

class itkScalarImageKmeansImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterISS3ISS3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterISS3ISS3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion3"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterISS3ISS3

        Create a new object of the class itkScalarImageKmeansImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterISS3ISS3 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3ISS3_swigregister(itkScalarImageKmeansImageFilterISS3ISS3)

def itkScalarImageKmeansImageFilterISS3IUC3_New():
    return itkScalarImageKmeansImageFilterISS3IUC3.New()

class itkScalarImageKmeansImageFilterISS3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3IUC3):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterISS3IUC3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterISS3IUC3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion3"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterISS3IUC3

        Create a new object of the class itkScalarImageKmeansImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterISS3IUC3 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterISS3IUC3_swigregister(itkScalarImageKmeansImageFilterISS3IUC3)

def itkScalarImageKmeansImageFilterIUC2ISS2_New():
    return itkScalarImageKmeansImageFilterIUC2ISS2.New()

class itkScalarImageKmeansImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2ISS2):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIUC2ISS2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIUC2ISS2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion2"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIUC2ISS2

        Create a new object of the class itkScalarImageKmeansImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIUC2ISS2 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2ISS2_swigregister(itkScalarImageKmeansImageFilterIUC2ISS2)

def itkScalarImageKmeansImageFilterIUC2IUC2_New():
    return itkScalarImageKmeansImageFilterIUC2IUC2.New()

class itkScalarImageKmeansImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIUC2IUC2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIUC2IUC2_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion2"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIUC2IUC2

        Create a new object of the class itkScalarImageKmeansImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIUC2IUC2 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC2IUC2_swigregister(itkScalarImageKmeansImageFilterIUC2IUC2)

def itkScalarImageKmeansImageFilterIUC3ISS3_New():
    return itkScalarImageKmeansImageFilterIUC3ISS3.New()

class itkScalarImageKmeansImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3ISS3):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIUC3ISS3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIUC3ISS3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion3"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIUC3ISS3

        Create a new object of the class itkScalarImageKmeansImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIUC3ISS3 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3ISS3_swigregister(itkScalarImageKmeansImageFilterIUC3ISS3)

def itkScalarImageKmeansImageFilterIUC3IUC3_New():
    return itkScalarImageKmeansImageFilterIUC3IUC3.New()

class itkScalarImageKmeansImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkScalarImageKmeansImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageKmeansImageFilterIUC3IUC3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageKmeansImageFilterIUC3IUC3_Pointer"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_Clone(self)

    def AddClassWithInitialMean(self, mean):
        r"""
        AddClassWithInitialMean(self, mean)

        Parameters
        ----------
        mean: double

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_AddClassWithInitialMean(self, mean)

    def GetFinalMeans(self):
        r"""GetFinalMeans(self) -> itkArrayD"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_GetFinalMeans(self)

    def SetUseNonContiguousLabels(self, _arg):
        r"""
        SetUseNonContiguousLabels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_SetUseNonContiguousLabels(self, _arg)

    def GetUseNonContiguousLabels(self):
        r"""GetUseNonContiguousLabels(self) -> bool const &"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_GetUseNonContiguousLabels(self)

    def UseNonContiguousLabelsOn(self):
        r"""UseNonContiguousLabelsOn(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_UseNonContiguousLabelsOn(self)

    def UseNonContiguousLabelsOff(self):
        r"""UseNonContiguousLabelsOff(self)"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_UseNonContiguousLabelsOff(self)

    def SetImageRegion(self, region):
        r"""
        SetImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_SetImageRegion(self, region)

    def GetImageRegion(self):
        r"""GetImageRegion(self) -> itkImageRegion3"""
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_GetImageRegion(self)
    InputHasNumericTraitsCheck = _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkScalarImageKmeansImageFilterPython.delete_itkScalarImageKmeansImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageKmeansImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageKmeansImageFilterIUC3IUC3

        Create a new object of the class itkScalarImageKmeansImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageKmeansImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageKmeansImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageKmeansImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageKmeansImageFilterIUC3IUC3 in _itkScalarImageKmeansImageFilterPython:
_itkScalarImageKmeansImageFilterPython.itkScalarImageKmeansImageFilterIUC3IUC3_swigregister(itkScalarImageKmeansImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def scalar_image_kmeans_image_filter(*args: itkt.ImageLike,  use_non_contiguous_labels: bool=..., image_region: itkt.ImageRegion=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ScalarImageKmeansImageFilter"""
    import itk

    kwarg_typehints = { 'use_non_contiguous_labels':use_non_contiguous_labels,'image_region':image_region }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ScalarImageKmeansImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def scalar_image_kmeans_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKClassifiers.ScalarImageKmeansImageFilter
    scalar_image_kmeans_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    scalar_image_kmeans_image_filter.__doc__ = filter_object.__doc__



